@@ -20,7 +20,7 @@
 #'  CACTVS HASHISY, NSC number, PubChem SID, ZINC Code, ChemSpider ID,
 #'  ChemNavigator SID, eMolecule VID.
 #'
-#'  \code{cir_query()} can handle only a part of all possible conversions of CIR.
+#'  \code{cir()} can handle only a part of all possible conversions of CIR.
 #'  Possible \code{representations} are:
 #'  \itemize{
 #'      \item \code{'smiles'}(SMILES strings),
@@ -82,7 +82,7 @@
 #' @note You can only make 1 request per second (this is a hard-coded feature).
 #'
 #' @references
-#' \code{cir_query} relies on the great CIR web service created by the CADD
+#' \code{cir} relies on the great CIR web service created by the CADD
 #' Group at NCI/NIH! \cr
 #' \url{http://cactus.nci.nih.gov/chemical/structure_documentation}, \cr
 #' \url{http://cactus.nci.nih.gov/blog/?cat=10}, \cr
@@ -94,25 +94,23 @@
 #' @examples
 #' \donttest{
 #' # might fail if API is not available
-#' cir_query('Triclosan', 'cas')
-#' cir_query("3380-34-5", 'cas')
-#' cir_query("3380-34-5", 'cas', resolver = 'cas_number')
-#' cir_query("3380-34-5", 'smiles')
-#' cir_query('Triclosan', 'mw')
-#' cir_query('Triclosan', 'aromatic')
-#' cir_query('Triclosan', 'xlogp2')
+#' cir('Triclosan', 'cas')
+#' cir("3380-34-5", 'cas')
+#' cir("3380-34-5", 'cas', resolver = 'cas_number')
+#' cir("3380-34-5", 'smiles')
+#' cir('Triclosan', 'mw')
 #'
 #' # query multiple representations
-#' reps <- c('smiles', 'cas', 'stdinchikey', 'mw', 'formula', 'xlogp2')
-#' sapply(reps, function(x) cir_query('Triclosan', x, first = TRUE))
+#' reps <- c('smiles', 'cas')
+#' sapply(reps, function(x) cir('Triclosan', x, first = TRUE))
 #'
 #' # multiple inputs
 #' comp <- c('Triclosan', 'Aspirin')
-#' sapply(comp, function(x) cir_query(x, 'cas', first = TRUE))
+#' sapply(comp, function(x) cir(x, 'cas', first = TRUE))
 #'
 #'}
 #' @export
-cir_query <- function(identifier, representation = 'smiles', resolver = NULL,
+cir <- function(identifier, representation = 'smiles', resolver = NULL,
                       first = FALSE, verbose = TRUE, ...){
   if (length(identifier) > 1) {
     stop('Cannot handle multiple input strings.')
