@@ -15,6 +15,7 @@ test_that("get_etoxid returns correct results", {
   do <- get_etoxid('Triclosan')
   xx <- get_etoxid('xxxxx')
 
+  expect_error(get_etoxid(c('Triclosan', 'xxx')))
   expect_equal(c(do), "20179")
   expect_equal(attr(do, "matched"), "Triclosan ( 20179 )")
   expect_equal(c(xx), NA)
@@ -27,6 +28,7 @@ test_that("etox_basic returns correct results", {
   do2 <- etox_basic('20179')
   xx2 <- etox_basic('xxx')
 
+  expect_error(etox_basic(c('20179', 'xxx')))
   expect_equal(do2$cas, "3380-34-5")
   expect_equal(length(do2), 4)
   expect_is(do2$synonyms, 'data.frame')
@@ -41,6 +43,7 @@ test_that("etox_targets returns correct results", {
   xx3 <- etox_targets('xxxx')
   xxx3 <- etox_targets('9051')
 
+  expect_error(etox_targets(c('20179', 'xxx')))
   expect_equal(do3$Substance[1], "Triclosan")
   expect_equal(ncol(do3), 32)
   expect_is(do3, 'data.frame')
@@ -54,6 +57,7 @@ test_that("etox_tests returns correct results", {
   do4 <- etox_tests('20179')
   xx4 <- etox_tests('xxxx')
 
+  expect_error(etox_tests(c('20179', 'xxx')))
   expect_equal(do4$Substance[1], "Triclosan")
   expect_equal(ncol(do4), 41)
   expect_is(do4, 'data.frame')
